import { GdsElement } from '../../gds-element';
/**
 * @element gds-form-summary
 *
 * When a user attempts to submit a form with errors, this component displays a summary of those errors.
 * Including an error summary greatly assists users in promptly identifying and addressing multiple errors
 * in a consolidated manner. It provides a clear indication of what went wrong and what needs to be corrected.
 */
export declare class GdsFormSummary extends GdsElement {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Whether to hide the error messages under the labels.
     */
    hideErrors: boolean;
    /**
     * Whether to refresh the summary automatically as controls in the form change validation state.
     *
     * Avoid this setting if the summary is located above the form controls, as it may cause the form
     * to jump around as the summary is updated.
     */
    reactive: boolean;
    /**
     * The current number of errors displayed in the summary.
     *
     * This is a convenience property that can be used to display the number of errors in the summary.
     */
    get errorCount(): number;
    /**
     * Focuses the first focusable element in the summary.
     */
    focus(options?: FocusOptions): void;
    private _elRoot;
    connectedCallback(): void;
    disconnectedCallback(): void;
    /**
     * Refresh the component to reflext the current state of the form.
     */
    refresh(): void;
    render(): any;
}
